===================
Stage XY - Template
===================

**Short statement of the stage's purpose**

`config template <https://github.com/INM-6/cobrawap/master/editing/pipeline/stageXY_template/configs/config_template.yaml>`_

Input
=====
Describe type and format of the minimally required data and metadata.

*should pass* |check_input|_

.. |check_input| replace:: *check_input.py*
.. _check_input: https://github.com/INM-6/cobrawap/master/editing/pipeline/stageXY_template/scripts/check_input.py

Output
======
Describe type and format of the stage output data and metadata, eventual intermediate output, and where it is stored.

Usage
=====
Describe the functionality of the stage, what type of blocks are used and how they can be arranged, and eventually special stage parameters. However, an account of the exact blocks and their features should be placed into the Snakefile's and scripts' docstring.